import uvicorn
from fastapi import FastAPI
from loguru import logger
from tompy.settings import BaseSettings

from otlpy.api.v1 import v1
from otlpy.base.util import makedirs


class Settings(BaseSettings):
    otlsvr_host: str
    otlsvr_port: int


app = FastAPI()
app.include_router(v1)


@app.on_event("startup")
async def startup() -> None:
    pass


@app.on_event("shutdown")
async def shutdown() -> None:
    pass


@app.get("/")
async def root() -> dict[str, str]:
    return {"Hello": "World"}


if __name__ == "__main__":
    SAVEDIR = "./save"
    LOGFILE = "./save/otlsvr.log"
    makedirs(SAVEDIR)
    logger.add(LOGFILE)
    settings = Settings()
    uvicorn.run(app, host=settings.otlsvr_host, port=settings.otlsvr_port)
