from enum import Enum

from otlpy.model.base import BaseModel


class INTERVAL(str, Enum):
    D1 = "D1"


class PQ(BaseModel):
    p: str  # Price
    q: str  # Qty


class OrderBook(BaseModel):
    mstime: int
    ticker: str
    bids: list[PQ]
    asks: list[PQ]


class Candlestick(BaseModel):
    ot: int  # Open Time
    o: str  # Open
    h: str  # High
    l: str  # Low
    c: str  # Close
    v: str  # Volume
    ct: int  # Close Time


class ORDER_SIDE(str, Enum):
    BUY = "BUY"
    SELL = "SELL"


class ORDER_TYPE(str, Enum):
    LIMIT = "LIMIT"
    MARKET = "MARKET"


class Order(BaseModel):
    oside: ORDER_SIDE
    otype: ORDER_TYPE
    ticker: str
    qty: str
    price: str
    comment: str


class Buy(Order):
    pass


class Sell(Order):
    pass


class Cancel(Order):
    origin: Order


class InBuy(BaseModel):
    otype: ORDER_TYPE
    ticker: str
    qty: str
    price: str
    comment: str


class InSell(BaseModel):
    otype: ORDER_TYPE
    ticker: str
    qty: str
    price: str
    comment: str


class InCancel(BaseModel):
    origin: Order
    comment: str


class InOrders(BaseModel):
    first: Order
